@@ -1,6 +1,6 @@
 # ************************************************************************************
-# TO DO: 
-  # x) Extend the checking for non_TD pars to TD parents in find_FormVars() 
+# TO DO:
+  # x) Extend the checking for non_TD pars to TD parents in find_FormVars()
   # x) For non_TD var outside of the DAG also check that length(non_TD) < 2
   # x) => Want to allow vectors in user.env to be referenced as uservec[t]
   # x) => This will allow avoiding declaration of node attributes as nodes, will save a ton of memory
@@ -26,11 +26,11 @@ vector_math_fcns <- c("I","abs","sign","sqrt","round","signif","floor","ceil","c
 # b) find baseline var calls;
 # c) parse the tree at most 10 times and evaluate all atomic expressions
 # d) modify calls to summary (non-vectorized) function to apply(DF, 1, func_name), adding cbind to calls with more than 1 arg
-nodeform_parsers = function(node_form_call, data.env, user.env)  {
+nodeform_parsers = function(node_form_call, data.env, user.env, self)  {
   # combine all default vectorized funs + the user-specified vectorized function in global :
   vector_fcns_all <- c(vector_fcns, vector_ops_fcns, vector_math_fcns, vecfun.get())
   curr.dfvarnms <- data.env[["ANCHOR_ALLVARNMS_VECTOR_0"]]
-  # 
+  #
   # (not USED) SUMMARY FCNS (non-vectorized): these will be always turned into apply(arg, 1, func)
   # summary_fcns <- c("c","all","any","sum","mean","prod","min","max","range")
   # (not USED) FOR FUTURE IMPLEMENTATION: FUNCTION NAMES THAT AREN'T ALLOWED IN FORMULA EXPRESSIONS:
@@ -39,11 +39,11 @@ nodeform_parsers = function(node_form_call, data.env, user.env)  {
   # * recursively parse the call tree structure for a given expression, find call to '[' or a name, then output that name (TDVar name will be called as TDVar[])
 
   # ************************************************************************************
-  # TO DO: 
+  # TO DO:
   # Extend the same checks for non_TD var existance to TD vars => Want to allow vectors in user.env to be referenced as uservec[t]
   # When TDvar_t not in DAG, check that TD_var exists in user.env, check that its a vector and that length matches t length
   # Decide between method I & II for finding non_TD parents
-  # Curently using method I for non_TD vars, plotting DAG will exclude 
+  # Curently using method I for non_TD vars, plotting DAG will exclude
   # ************************************************************************************
 
   find_FormVars <- function(x, vartype="TD") {
@@ -59,7 +59,7 @@ nodeform_parsers = function(node_form_call, data.env, user.env)  {
       dprint("is x in DAG? " %+% is.inDAG);
 
       # CHECK FOR UNDECLARED VARS: Verify if x is defined in user env if (!notis.fun & !is.inDAG)
-      # exists.x <- exists(as.character(x), where = user.env, inherits = FALSE) 
+      # exists.x <- exists(as.character(x), where = user.env, inherits = FALSE)
       exists.x <- exists(as.character(x), where = user.env, inherits = TRUE)
       dprint("does x exist in user.env? " %+% exists.x)
 
@@ -68,15 +68,18 @@ nodeform_parsers = function(node_form_call, data.env, user.env)  {
       special <- as.character(x) %in% specialVar
       dprint("is x special? " %+% special)
 
-      if (notis.fun && !is.inDAG && !exists.x && !special) stop("Undefined variable: " %+% as.character(x), call. = FALSE)
+
+      if (notis.fun && !is.inDAG && !exists.x && !special) {
+        stop("Undefined variable: " %+% as.character(x), call. = FALSE)
+        # if (identical(x[[1]], quote(.)) || identical(x[[1]], quote(eval))) { # do nothing, don't parse the expressions wrapped in .()
+        # character()
+      }
 
       # ****************************
       # *) For non_TD var outside of the DAG also check that length(non_TD) < 2
       # ****************************
-
       # if (is.inDAG) varnames <- as.character(x) # METHOD I declares only vars that exist in the DAG as a parent
       if (notis.fun) varnames <- as.character(x) # METHOD II declares any nonfun var as a parent
-
     } else if (is.atomic(x) || is.name(x)) {
       character()
     } else if (is.call(x)) {
@@ -106,7 +109,8 @@ nodeform_parsers = function(node_form_call, data.env, user.env)  {
     } else if (is.pairlist(x)) {
       unique(unlist(lapply(x, find_FormVars, vartype)))
     } else {
-      stop("Don't know how to handle type ", typeof(x), call. = FALSE)
+      message("Don't know the expression result type ", typeof(x), call. = FALSE)
+      character()
     }
   }
 
@@ -117,7 +121,9 @@ nodeform_parsers = function(node_form_call, data.env, user.env)  {
         x	# Leave unchanged
       } else if (is.call(x)) {
         # reached '[', '[[' or 'c' functions, don't need to parse any deeper, return this subtree intact
-        if (((identical(x[[1]], quote(`[`)) || identical(x[[1]], quote(`[[`))) && is.name(x[[2]])) || identical(x[[1]], quote(c))) {
+        if (identical(x[[1]], quote(.)) || identical(x[[1]], quote(eval))) { # Call to .() or eval(), so evaluate and don't go any deeper
+          eval(x[[2]], envir = data.env, enclos = user.env)
+        } else if (((identical(x[[1]], quote(`[`)) || identical(x[[1]], quote(`[[`))) && is.name(x[[2]])) || identical(x[[1]], quote(c))) {  #|| identical(x[[1]], quote(.)) || identical(x[[1]], quote(eval))
           x # Leave unchanged
         } else {
           atomargs_test <- sapply(2:length(x), function(i) is.atomic(x[[i]]))
@@ -133,7 +139,9 @@ nodeform_parsers = function(node_form_call, data.env, user.env)  {
       } else if (is.pairlist(x)) {
         as.pairlist(lapply(x, eval_atomic, where = where))
       } else { # User supplied incorrect input
-        stop("Don't know how to handle type ", typeof(x), call. = FALSE)
+        message("Don't know the expression result type ", typeof(x), call. = FALSE)
+        # stop("Don't know how to handle type ", typeof(x), call. = FALSE)
+        x # Leave unchanged
       }
     } # end of eval_atomic()
 
@@ -158,7 +166,7 @@ nodeform_parsers = function(node_form_call, data.env, user.env)  {
   # * modify the call tree with apply for non-vectorized (summary) functions, also adding cbind_mod() for calls with more than one arg
   # * TO ADD: if call tree starts with '{' need to process each argument as a separate call and return a list of calls instead
   modify_call <- function (x, where = parent.frame()) {
-    if (is.atomic(x) & length(x)>1) {
+    if (is.atomic(x) & length(x)>1 & !is.matrix(x)) {
       x <- parse(text = deparse(x, width.cutoff = 500))[[1]]
       modify_call(x, where = where)	# continue parsing recursively, turning result back into call
     }
@@ -167,7 +175,9 @@ nodeform_parsers = function(node_form_call, data.env, user.env)  {
       if (is.name(x)) dprint("name: "%+%x)
       x	# Leave unchanged
     } else if (is.call(x)) {
-      if (identical(x[[1]], quote(`[`)) && is.name(x[[2]])) {	# reached '[' function, don`t need to parse any deeper, return this subtree intact
+      if (identical(x[[1]], quote(.)) || identical(x[[1]], quote(eval))) { # Call to .() or eval(), so evaluate and don't go any deeper
+        eval(x[[2]], envir = data.env, enclos = user.env)
+      } else if (identical(x[[1]], quote(`[`)) && is.name(x[[2]])) {	# reached '[' function, don`t need to parse any deeper, return this subtree intact
         x
       } else if (identical(x[[1]], quote(`[[`)) && is.name(x[[2]])) { # reached '[[' function, same as above
         x
@@ -186,8 +196,7 @@ nodeform_parsers = function(node_form_call, data.env, user.env)  {
           x[[1]] <- quote(rowMeans)	# check if the function is 'mean', in which case replace call with 'colMeans'
           as.call(lapply(x, modify_call, where = where))	# continue parsing recursively, turning result back into call
         } else if (identical(x[[1]], quote(structure))) {
-          modify_call(as.call(x[[2]]), where = where)  # continue parsing recursively, turning result back into call          
-          # as.call(lapply(x[[2]], modify_call, where = where))  # continue parsing recursively, turning result back into call          
+          modify_call(as.call(x[[2]]), where = where)  # continue parsing recursively, turning result back into call
         } else {
           nargs <- length(x)-1
           if (nargs > 1) { # IF NON-VECTORIZED func has more than one argument, combine all args into one with cbind_mod
@@ -210,31 +219,46 @@ nodeform_parsers = function(node_form_call, data.env, user.env)  {
     } else if (is.pairlist(x)) {
       as.pairlist(lapply(x, modify_call, where = where))
     } else { # User supplied incorrect input
-      stop("Don't know how to handle type ", typeof(x), call. = FALSE)
+      message("Don't know the expression result type ", typeof(x), call. = FALSE)
+      # stop("Don't know how to handle type ", typeof(x), call. = FALSE)
+      x # Leave unchanged
     }
   }
 
+
   # eval_atom_call <- node_form_call						      # don't evaluate any atomic expressions
   eval_atom_call <- eval_all_atomic(node_form_call)		# pre-evaluate all atomic expressions
+  dprint("after atomic evalulation:"); dprint(eval_atom_call)
+
+  # If t is present (defined) for current node, replace all "t" in node formula by its actual value:
+  if (!is.null(self$cur.node$t)) {
+    eval_atom_call <- eval(substitute(substitute(e, list(t = eval(self$cur.node$t))), list(e = eval_atom_call)))
+  }
+  # If network is present replace all "Kmax" in the node formula by the actual network Kmax value:
+  if (!is.null(self$netind_cl) && ("NetIndClass" %in% class(self$netind_cl))) {
+    eval_atom_call <- eval(substitute(substitute(e, list(Kmax = eval(self$netind_cl$Kmax))), list(e = eval_atom_call)))
+  }
+
+  dprint("after atomic evalulation and substitution:"); dprint(eval_atom_call)
+
 
   # Parses the formula and gets all the variable names referenced as [] or as.name==TRUE
   Vnames <- find_FormVars(eval_atom_call, vartype="non_TD")	# returns unique names of none TD vars that were called as VarName
   TD_vnames <- find_FormVars(eval_atom_call, vartype="TD")	# returns unique names TDVar that were called as TDVar[indx]
   TD_t_vnames <- find_FormVars(eval_atom_call, vartype="TD_t") # returns unique names TDVar_t that were called as TDVar[indx]
-
   dprint("Vnames: "); dprint(Vnames)
   dprint("TD_vnames: "); dprint(TD_vnames)
   dprint("TD_t_vnames: "); dprint(TD_t_vnames)
 
   modified_call <- modify_call(eval_atom_call) 			# parse current call and replace any non-vectorized function with apply call (adding cbind_mod if more than one arg)
-  dprint("modified_call"); dprint(modified_call)
+  dprint("modified_call:"); dprint(modified_call)
 
   return(list(Vnames = Vnames, TD_vnames = TD_vnames, TD_t_vnames = TD_t_vnames, modified_call = modified_call))
 }
 
 eval.nodeform.full <- function(expr_call, expr_str, self, data.env) {
   # traverse the node formula call, return TDvar & Var names (node parents) and modify subst_call to handle non-vectorized (summary functions):
-  parse_res <- nodeform_parsers(node_form_call = expr_call, data.env = data.env, user.env = self$user.env)
+  parse_res <- nodeform_parsers(node_form_call = expr_call, data.env = data.env, user.env = self$user.env, self = self)
 
   # set the local variables in the formula node to their character values:
   Vnames  <- parse_res$Vnames
@@ -305,7 +329,7 @@ eval.nodeform.asis <- function(expr_call, expr_str, self, data.env) {
 # 2) finds all time-dep var names (Var[]) and non-time dep var names (Var)
 # 3) replaces all summary function calls, s.a., func(Var) with apply(Var, 1, func)
 # 4) replaces all calls to functions with several vectors, s.a., func(X1,X2,X3) with func(cbind(X1,X2,X3))
-# 5) evaluates final expression in a special environment where: 
+# 5) evaluates final expression in a special environment where:
   # -) variables that have been simulated so far in obs.df are accessible
   # -) the subset vector function '[' is replaces with its specialized version, with syntax TDVar[t_range] for subsetting columns of the observed data by time
   # -) vecapply() function that is a wrapper for apply, converts vector to a 1 col matrix
@@ -349,7 +373,6 @@ eval.nodeform.out <- function(expr.idx, self, data.df) {
   if (!is.null(self$cur.node$t)) {
     expr_call <- eval(substitute(substitute(e, list(t = eval(self$cur.node$t))), list(e = expr_call)))
   }
-
   # If network is present replace all "Kmax" in the node formula by the actual network Kmax value:
   if (!is.null(self$netind_cl) && ("NetIndClass" %in% class(self$netind_cl))) {
     expr_call <- eval(substitute(substitute(e, list(Kmax = eval(self$netind_cl$Kmax))), list(e = expr_call)))
@@ -383,6 +406,7 @@ parse.sVar.out <- function(sVar.idx, self, data.df) {
 
 ## ---------------------------------------------------------------------
 #' @title Class for defining and evaluating user-specified summary measures (exprs_list)
+#' @description Evaluates and and stores arbitrary summary measure expressions. The expressions (exprs_list) are evaluated in the environment of the input data.frame.
 #' @docType class
 #' @format An R6 class object.
 #' @name Define_sVar
@@ -394,8 +418,6 @@ parse.sVar.out <- function(sVar.idx, self, data.df) {
 #' \item{sW_nms} ...
 #' \item{Kmax} ...
 #' }
-#' Evaluates and and stores arbitrary summary measure expressions. 
-#' The expressions (exprs_list) are evaluated in the environment of the input data.frame.
 #' @importFrom R6 R6Class
 #' @importFrom assertthat assert_that
 # @export
@@ -412,7 +434,7 @@ Define_sVar <- R6Class("Define_sVar",
     asis.flags = list(),          # list of flags, TRUE for "as is" node expression evaluation
     ReplMisVal0 = FALSE,          # vector of indicators, for each TRUE sVar.expr[[idx]] will replace all NAs with gvars$misXreplace (0)
     sVar.misXreplace = NULL,      # replacement values for missing sVar, vector of length(exprs_list)
-    sVar.noname = FALSE,          # vector, for each TRUE sVar.expr[[idx]] ignores user-supplied name and generates names automatically    
+    sVar.noname = FALSE,          # vector, for each TRUE sVar.expr[[idx]] ignores user-supplied name and generates names automatically
 
     exprs_list = list(),          # sVar expressions as a list
     sVar.expr.names = character(),# user-provided name of each sVar.expr
@@ -438,10 +460,10 @@ Define_sVar <- R6Class("Define_sVar",
           Nsamp <- env$self$Nsamp
           assert_that(!is.null(Nsamp))
           if (Nsamp > 0) {
-            cbind_res <- matrix(cbind_res, nrow = Nsamp, ncol = ncol(cbind_res), byrow = TRUE)  
+            cbind_res <- matrix(cbind_res, nrow = Nsamp, ncol = ncol(cbind_res), byrow = TRUE)
           } else {
             cbind_res <- matrix(nrow = Nsamp, ncol = ncol(cbind_res), byrow = TRUE)
-          } 
+          }
         }
         dprint("cbind_res"); dprint(cbind_res)
         cbind_res
@@ -455,7 +477,6 @@ Define_sVar <- R6Class("Define_sVar",
         env <- parent.frame()
         # t <- env$t
         t <- env$self$cur.node$t
-
         var <- substitute(var)
         var.chr <- as.character(var)
 
@@ -467,16 +488,16 @@ Define_sVar <- R6Class("Define_sVar",
         if (identical(class(indx),"logical")) indx <- which(indx)
 
         # ******* NOTE *******
-        # Don't like the current implementation that defines TDvars as characters and then returns a matrix by cbinding 
+        # Don't like the current implementation that defines TDvars as characters and then returns a matrix by cbinding
         # the existing columins in existing data.frame. This is possibly wasteful. Could we instead subset the existing data.frame?
         TDvars <- var.chr%+%"_"%+%indx
         # Checking the variables paste0(var, "_", indx) exist in simulated data.frame environment:
         dprint("ANCHOR_ALLVARNMS_VECTOR_0:"); dprint(env[["ANCHOR_ALLVARNMS_VECTOR_0"]])
 
-        # ******* TO DO ******* 
+        # ******* TO DO *******
         # EXTEND TO CHECKING FOR TDvar IN ENCLOSING ENVIRONMENT (user.env) AS WELL IF TDvar_t doesn't exist in the data
         # IF TDvar exists check that its a vector of appropriate length, index it accordinly (using which(t%in%tvec))
-        # will need to first eval such vector the variable as in: 
+        # will need to first eval such vector the variable as in:
         # var.val <- eval(var, envir = env)
         existsTDVar <- function(TDvar_t) TDvar_t %in% env[["ANCHOR_ALLVARNMS_VECTOR_0"]]
         check_exist <- sapply(TDvars, existsTDVar)
@@ -518,7 +539,7 @@ Define_sVar <- R6Class("Define_sVar",
         if(inherits(var.val, "try-error")) {
           stop("\n...attempt to evaluate network indexing variable failed...")
         }
-        
+
         # if result is one column matrix -> convert to a vector, if matrix has >1 columns -> throw an error:
         if (length(dim(var.val)) > 1) {
           var.chr <- colnames(var.val)[1]
@@ -563,7 +584,7 @@ Define_sVar <- R6Class("Define_sVar",
       dprint("self$sVar.expr.names: "); dprint(self$sVar.expr.names)
 
       self$asis.flags <- attributes(exprs_list)[["asis.flags"]]
-      if (is.null(self$asis.flags)) { 
+      if (is.null(self$asis.flags)) {
         self$asis.flags <- as.list(rep.int(FALSE, length(exprs_list)))
         names(self$asis.flags) <- names(exprs_list)
       }
@@ -654,7 +675,7 @@ Define_sVar <- R6Class("Define_sVar",
       assert_that("NetIndClass" %in% class(netind_cl))
       self$netind_cl <- netind_cl
       invisible(self)
-    }    
+    }
   ),
 
   active = list(
